# Copyright The OpenTelemetry Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

from sys import argv

from requests import get

from opentelemetry import propagators, trace
from opentelemetry.ext import jaeger
from opentelemetry.sdk.trace.export import BatchExportSpanProcessor
from opentelemetry.sdk.trace import TracerProvider
from opentelemetry.sdk.trace.export import (
    ConsoleSpanExporter,
    SimpleExportSpanProcessor,
)
import requests

from opentelemetry import trace

#trace.set_tracer_provider(TracerProvider())

# jaeger_exporter = jaeger.JaegerSpanExporter(
#     service_name="CLIENT1-service",
#     agent_host_name="localhost",
#     agent_port=6831,
# )

trace.set_tracer_provider(TracerProvider())
tracer = trace.get_tracer_provider().get_tracer(__name__)

jaeger_exporter = jaeger.JaegerSpanExporter(
    service_name="Email-Service",
    agent_host_name="localhost",
    agent_port=6831,
)

trace.get_tracer_provider().add_span_processor(
    BatchExportSpanProcessor(jaeger_exporter)
)

with tracer.start_as_current_span("client1"):
    headers = {}
    propagators.inject(dict.__setitem__, headers)
    requested = get(
        "http://localhost:8000",
        headers=headers,
    )
